@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Acme::ProgressBar;
-BEGIN {
-  $Acme::ProgressBar::VERSION = '1.126';
+{
+  $Acme::ProgressBar::VERSION = '1.127';
 }
 # ABSTRACT: a simple progress bar for the patient
 
@@ -14,45 +14,48 @@ our @EXPORT = qw(progress); ## no critic Export
 
 
 sub progress(&) { ## no critic Prototype
-	my ($code) = @_;
-	local $| = 1; ## no critic
-	_overprint(_message(0,10,undef));
-	my $begun = Time::HiRes::time;
+  my ($code) = @_;
+  local $| = 1; ## no critic
+  _overprint(_message(0,10,undef));
+
+  my $begun = Time::HiRes::time;
   $code->();
-	my $total = Time::HiRes::time - $begun;
-	for (1 .. 9) {
-		_overprint(_message($_,10,$total));
-		Time::HiRes::sleep($total);
-	}
-	_overprint(_message(10,10,$total));
-	print "\n";
+  my $total = Time::HiRes::time - $begun;
+
+  for (1 .. 9) {
+    _overprint(_message($_,10,$total));
+    Time::HiRes::sleep($total);
+  }
+
+  _overprint(_message(10,10,$total));
+  print "\n";
 }
 
 sub _message {
-	my ($iteration, $total, $time) = @_;
-	my $message
-    = 'Progress: ['
-    .  q{=} x $iteration
-    .  q{ } x ($total - $iteration)
-    .  '] ';
+  my ($iteration, $total, $time) = @_;
+  my $message = 'Progress: ['
+              .  q{=} x $iteration
+              .  q{ } x ($total - $iteration)
+              .  '] ';
 
-	if (defined $time) {
-	  $message .= sprintf '%0.0fs remaining%25s',
-	    (($total - $iteration) * $time), q{ };
-	} else {
-	  $message .= '(calculating time remaining)';
-	}
+  if (defined $time) {
+    $message .= sprintf '%0.0fs remaining%25s',
+      (($total - $iteration) * $time), q{ };
+  } else {
+    $message .= '(calculating time remaining)';
+  }
 }
 
 sub _overprint {
-	my ($message) = @_;
-	print $message, "\r";
+  my ($message) = @_;
+  print $message, "\r";
 }
 
 
 "48102931829 minutes remaining";
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -61,7 +64,7 @@ Acme::ProgressBar - a simple progress bar for the patient
 
 =head1 VERSION
 
-version 1.126
+version 1.127
 
 =head1 SYNOPSIS
 
@@ -110,4 +113,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
